import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:orientation_screen/common/utils/ScreenOrientationMode.dart';

class OrientationScreen extends StatefulWidget {
  final Widget child;
  final ScreenOrientationMode orientationMode;

  OrientationScreen({@required this.child, this.orientationMode});

  @override
  _OrientationScreenState createState() => _OrientationScreenState();
}

class _OrientationScreenState extends State<OrientationScreen> {
  void _portraitModeOnly() {
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitUp,
      DeviceOrientation.portraitDown,
    ]);
  }

  void _landscapeModeOnly() {
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.landscapeLeft,
      DeviceOrientation.landscapeRight,
    ]);
  }

  void _enableRotation() {
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitUp,
      DeviceOrientation.portraitDown,
      DeviceOrientation.landscapeLeft,
      DeviceOrientation.landscapeRight,
    ]);
  }

  @override
  void initState() {
    ScreenOrientationMode orientation =
        widget.orientationMode ?? ScreenOrientationMode.auto;
    if (orientation == ScreenOrientationMode.landscapeOnly) {
      _landscapeModeOnly();
    } else if (orientation == ScreenOrientationMode.portraitOnly) {
      _portraitModeOnly();
    } else {
      _enableRotation();
    }
    super.initState();
  }

  @override
  void dispose() {
    _enableRotation();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return widget.child;
  }
}
